==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/src/x11/form.h <==
#if 0
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.
#endif
#ifndef FORM_H
#define FORM_H

#include <X11/Core.h>

#if 0
 Name            Class        RepType    Default Value
-------------------------------------------------------------------
 background      Background   Pixel      XtDefaultBackground
 border          BorderColor  Pixel      XtDefaultForeground
 borderWidth     BorderWidth  Dimension  1
 defaultDistance Thickness    int        4
 destroyCallback Callback     Pointer    NULL
 height          Height       Dimension  computed at realize
 mappedWhenManaged MappedWhenManaged Boolean True
 sensitive       Sensitive    Boolean    True
 width           Width        Dimension  computed at realize
 x               Position     Position   0
 y               Position     Position   0
-------------------------------------------------------------------
#endif

typedef struct _FormClassRec *FormWidgetClass;
typedef struct _FormRec *FormWidget;
extern WidgetClass formWidgetClass;
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/src/x11/form.h <==
#if 0
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.
#endif
#ifndef FORM_H
#define FORM_H

#include <X11/Core.h>

#if 0
 Name            Class        RepType    Default Value
-------------------------------------------------------------------
 background      Background   Pixel      XtDefaultBackground
 border          BorderColor  Pixel      XtDefaultForeground
 borderWidth     BorderWidth  Dimension  1
 defaultDistance Thickness    int        4
 destroyCallback Callback     Pointer    NULL
 height          Height       Dimension  computed at realize
 mappedWhenManaged MappedWhenManaged Boolean True
 sensitive       Sensitive    Boolean    True
 width           Width        Dimension  computed at realize
 x               Position     Position   0
 y               Position     Position   0
-------------------------------------------------------------------
#endif

typedef struct _FormClassRec *FormWidgetClass;
typedef struct _FormRec *FormWidget;
extern WidgetClass formWidgetClass;
#endif
